@@ -9,7 +9,6 @@ import requests
 import tldextract
 from loguru import logger
 from tenacity import retry, stop_after_attempt, wait_random
-from distutils.util import strtobool
 
 
 def rmdir(dir_location):
@@ -72,7 +71,7 @@ class RundeckJobs(object):
             uptimerobot_api_key: str = os.environ.get(
                 "RD_OPTION_UPTIMEROBOT_API_KEY"),
             fqdn: str = os.environ.get("RD_OPTION_FQDN"),
-            force_apply: bool = strtobool(os.environ.get('RD_OPTION_FORCE_APPLY'))):
+            force_apply: str = os.environ.get('RD_OPTION_FORCE_APPLY')):
         if deployment_action != 'apply':
             print("Skipping website hosting check as deployment action is not apply")
             exit(0)
@@ -91,7 +90,7 @@ class RundeckJobs(object):
         if not matched_monitors:
             print(f"{fqdn} seems to be a new site, skipping!")
             exit(0)
-        elif force_apply:
+        elif force_apply in ['true', 'True', True]:
             print("Force apply is requested, ignoring check results")
             exit(0)
         else:
